@@ -2,18 +2,19 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-use sp_std::{
+use alloc::{
   borrow::Borrow,
+  vec::Vec,
+};
+
+use core::{
   cmp::Ordering,
   mem,
   ops::{
     Bound,
     RangeBounds,
   },
-  vec,
-  vec::Vec,
 };
-
 use sp_sized_chunks::Chunk;
 
 use crate::{
@@ -1310,7 +1311,7 @@ where A: 'a + BTreeValue + PartialEq
         },
         (Some(old), Some(new)) => match (old, new) {
           (IterItem::Consider(old), IterItem::Consider(new)) => {
-            if !sp_std::ptr::eq(old, new) {
+            if !core::ptr::eq(old, new) {
               match old.keys[0].cmp_values(&new.keys[0]) {
                 Ordering::Less => {
                   Self::push(&mut self.old_stack, &old);
