@@ -17,18 +17,22 @@
 //! [hashset::HashSet]: ../hashset/struct.HashSet.html
 //! [std::cmp::Ord]: https://doc.rust-lang.org/std/cmp/trait.Ord.html
 
-use sp_std::{
+use alloc::{
   borrow::{
     Borrow,
     ToOwned,
   },
-  cmp::Ordering,
   collections::btree_set,
   fmt::{
     Debug,
     Error,
     Formatter,
   },
+  vec::Vec,
+};
+
+use core::{
+  cmp::Ordering,
   hash::{
     Hash,
     Hasher,
@@ -44,7 +48,6 @@ use sp_std::{
     Mul,
     RangeBounds,
   },
-  vec::Vec,
 };
 
 #[cfg(has_specialisation)]
@@ -268,7 +271,7 @@ impl<A> OrdSet<A> {
   ///
   /// Time: O(1)
   pub fn ptr_eq(&self, other: &Self) -> bool {
-    sp_std::ptr::eq(self, other) || PoolRef::ptr_eq(&self.root, &other.root)
+    core::ptr::eq(self, other) || PoolRef::ptr_eq(&self.root, &other.root)
   }
 
   /// Get a reference to the memory pool used by this set.
